# Changelog

All notable changes to this project will be documented in this file.

## [Ideas]

- Add an OpenRC init script

## [Unreleased]

- None.

## [0.0.1] - 2020-05-10

### Added

- Initial Python 3 version.

### Changed

- None.

### Removed

- None.
